@@ -1,5 +1,5 @@
 /*
- * kafkacat - Apache Kafka consumer and producer
+ * kcat - Apache Kafka consumer and producer
  *
  * Copyright (c) 2019, Magnus Edenhill
  * All rights reserved.
@@ -26,7 +26,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "kafkacat.h"
+#include "kcat.h"
 #include <libserdes/serdes-avro.h>
 
 static serdes_t *serdes;
@@ -118,7 +118,7 @@ void kc_avro_term (void) {
  *
  * @returns newly allocated JSON string, or NULL on error.
  */
-char *kc_avro_to_json (const void *data, size_t data_len,
+char *kc_avro_to_json (const void *data, size_t data_len, int *schema_idp,
                        char *errstr, size_t errstr_size) {
         avro_value_t avro;
         serdes_schema_t *schema;
@@ -148,6 +148,9 @@ char *kc_avro_to_json (const void *data, size_t data_len,
                 return NULL;
         }
 
+        if (schema && schema_idp)
+                *schema_idp = serdes_schema_id(schema);
+
         avro_value_decref(&avro);
 
         return json;
