@@ -1,5 +1,5 @@
 /*
- * kafkacat - Apache Kafka consumer and producer
+ * kcat - Apache Kafka consumer and producer
  *
  * Copyright (c) 2015, Magnus Edenhill
  * All rights reserved.
@@ -26,7 +26,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "kafkacat.h"
+#include "kcat.h"
 #include "rdendian.h"
 
 static void fmt_add (fmt_type_t type, const char *str, int len) {
@@ -400,6 +400,7 @@ static void fmt_msg_output_str (FILE *fp,
                                         char *json = kc_avro_to_json(
                                                 rkmessage->key,
                                                 rkmessage->key_len,
+                                                NULL,
                                                 errstr, sizeof(errstr));
 
                                         if (!json) {
@@ -446,8 +447,8 @@ static void fmt_msg_output_str (FILE *fp,
                                         char *json = kc_avro_to_json(
                                                 rkmessage->payload,
                                                 rkmessage->len,
-                                                errstr,
-                                                sizeof(errstr));
+                                                NULL,
+                                                errstr, sizeof(errstr));
 
                                         if (!json) {
                                                 what_failed =
